==> haskell-fsnotify-0.3.0.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-fsnotify.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fsnotify
version: 0.3.0.1
id: fsnotify-0.3.0.1-Cme7US5sejqLOdAs7CgO6I
key: fsnotify-0.3.0.1-Cme7US5sejqLOdAs7CgO6I
license: BSD-3-Clause
maintainer: Tom McLaughlin <tom@codedown.io>
author: Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage: https://github.com/haskell-fswatch/hfsnotify
synopsis: Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification,
    and deletion notification. This library builds upon
    existing libraries for platform-specific Windows, Mac,
    and Linux filesystem event notification.
category: Filesystem
abi: f60d7ed95b679dc1edd96f4c4c4bc649
exposed: True
exposed-modules:
    System.FSNotify System.FSNotify.Devel
hidden-modules: System.FSNotify.Listener System.FSNotify.Path
                System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux
import-dirs: /usr/lib/ghc-8.4.3/site-local/fsnotify-0.3.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/fsnotify-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/fsnotify-0.3.0.1
hs-libraries: HSfsnotify-0.3.0.1-Cme7US5sejqLOdAs7CgO6I
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    directory-1.3.1.5 filepath-1.4.2 text-1.2.3.0 time-1.8.0.2
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe
    unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y
    hinotify-0.3.10-1hds7Zybs3sLhehpuSG4Xi
    shelly-1.8.1-AU8OVTLPnlX3tbcGj4ZR2o unix-2.7.2.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=32776142fda961cc693aa4db742773f9
             unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y=31a73ccc78f384281114d092d52191fc
             hinotify-0.3.10-1hds7Zybs3sLhehpuSG4Xi=b7593bb519dcb82e179621afc05b8a8e
             shelly-1.8.1-AU8OVTLPnlX3tbcGj4ZR2o=b30f67e801f1de2722bde66e41d2fafe
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
haddock-interfaces: /usr/share/doc/haskell-fsnotify/html/fsnotify.haddock
haddock-html: /usr/share/doc/haskell-fsnotify/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fsnotify-0.3.0.1-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-fsnotify.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fsnotify
version: 0.3.0.1
id: fsnotify-0.3.0.1-H5MXu8F5OtRLMrogrMM0G0
key: fsnotify-0.3.0.1-H5MXu8F5OtRLMrogrMM0G0
license: BSD-3-Clause
maintainer: Tom McLaughlin <tom@codedown.io>
author: Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage: https://github.com/haskell-fswatch/hfsnotify
synopsis: Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification,
    and deletion notification. This library builds upon
    existing libraries for platform-specific Windows, Mac,
    and Linux filesystem event notification.
category: Filesystem
abi: 02850fbc02efa7e465b380cecabfc722
exposed: True
exposed-modules:
    System.FSNotify System.FSNotify.Devel
hidden-modules: System.FSNotify.Listener System.FSNotify.Path
                System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux
import-dirs: /usr/lib/ghc-8.4.3/site-local/fsnotify-0.3.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/fsnotify-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/fsnotify-0.3.0.1
hs-libraries: HSfsnotify-0.3.0.1-H5MXu8F5OtRLMrogrMM0G0
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    directory-1.3.1.5 filepath-1.4.2 text-1.2.3.0 time-1.8.0.2
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe
    unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y
    hinotify-0.3.10-1hds7Zybs3sLhehpuSG4Xi
    shelly-1.8.1-EzSjalQCygsEzXxFFKxxIR unix-2.7.2.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=32776142fda961cc693aa4db742773f9
             unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y=31a73ccc78f384281114d092d52191fc
             hinotify-0.3.10-1hds7Zybs3sLhehpuSG4Xi=b7593bb519dcb82e179621afc05b8a8e
             shelly-1.8.1-EzSjalQCygsEzXxFFKxxIR=464664717f5b59614d280e3c53b8479d
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
haddock-interfaces: /usr/share/doc/haskell-fsnotify/html/fsnotify.haddock
haddock-html: /usr/share/doc/haskell-fsnotify/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
